\name{CIN}
\alias{fCINGEC}
\alias{fSingleCINGEC}
\title{Chromosomal Instability (CIN) Signature Index}
\description{
Functions to estimate CIN signature index based on MAS5-processed Affymetrix GeneChip data.
}
\usage{
  fCINGEC(x, val.type="in")
  fSingleCINGEC(x, med, val.type="in")
}
\arguments{
  \item{x}{a numeric matrix (\code{fCINGEC}: gene expression matrix) or a numeric vector (\code{fSingleCINGEC}: gene expression vector).}
  \item{med}{a numeric vector (median values for probe(set)s).}
  \item{val.type}{either "intensity" or "logintensity" or "logratio" (value type of \code{x})}
}
\details{
\code{fCINGEC} estimates prognostic signature indices of samples in an Affymetrix GeneChip gene expression matrix \code{x}. Preferably, the matrix is supposed to be MAS5-processed but this is not absolutely necessary as far as the row names bear original probesets while columns correspond to samples as usual. 

\code{fSingleCINGEC} estimates a prognostic signature index for a named vector \code{x} which corresponds to an individual sample (column vector) of a gene expression matrix.

For implementation details, please refer to \code{\link{fCentroIndex}}.
}
\value{
A numeric vector (per each sample/column) for \code{fCINGEC}. 

A number for \code{fSingleCINGEC}.
}
\references{
Chung TH, Mulligan G, Fonseca R, Chng WJ (2013) A novel measure of chromosome instability can account for prognostic difference in multiple myeloma. \emph{PLoS ONE} \strong{8:}e66361.
}
\author{Tae-Hoon Chung}
\seealso{See also \code{\link{fGeneSigPack}}.}
\examples{
library(MMGeneSigIndex)
\donttest{data(hovontest)}

## .. case of using intensity data
\donttest{gsig <- fCINGEC(hovontest)}

## .. case of using logratio data
\donttest{med <- apply(hovontest, 1, median)}
\donttest{logr <- log2(apply(hovontest, 2, function(x) x / med))}
\donttest{gsig2 <- fCINGEC(logr, val.type="logratio")}

## .. case of using fSingleCINGEC
\donttest{gsig3 <- apply(hovontest, 2, fSingleCINGEC, med)}

## .. sanity check
\donttest{plot(gsig, gsig2)}
\donttest{plot(gsig, gsig3)}
}
\keyword{math}
