\name{CellDeath}
\alias{fHZDCD}
\alias{fSingleHZDCD}
\title{Homozygously Deleted Cell Death Signature Index}
\description{
Functions to estimate HZDCD signature index based on MAS5-processed Affymetrix GeneChip data.
}
\usage{
  fHZDCD(x, val.type="in")
  fSingleHZDCD(x, med, val.type="in")
}
\arguments{
  \item{x}{a numeric matrix (\code{fHZDCD}: gene expression matrix) or a numeric vector (\code{fSingleHZDCD}: gene expression vector).}
  \item{med}{a numeric vector (median expression values for probe(set)s).}
  \item{val.type}{either "intensity" or "logintensity" or "logratio" (value type of \code{x})}
}
\details{
\code{fHZDCD} estimates prognostic signature indices of samples in an Affymetrix GeneChip gene expression matrix \code{x}. Preferably, the matrix is supposed to be MAS5-processed but this is not absolutely necessary as far as the row names bear original probesets while columns correspond to samples as usual. 

\code{fSingleHZDCD} estimates a prognostic signature index for a named vector \code{x} which corresponds to an individual sample (column vector) of a gene expression matrix.

For implementation details, please refer to \code{\link{fCentroIndex}}.
}
\value{
A numeric vector (per each sample/column) for \code{fHZDCD}. 

A number for \code{fSingleHZDCD}.
}
\references{
Dickens NJ, Walker BA, Leone PE, \emph{et al.} (2010) Homozygous deletion mapping in myeloma samples identifies genes and an expression signature relevant to pathogenesis and outcome. \emph{Clin Cancer Res} \strong{16:}1856–1864.
}
\author{Tae-Hoon Chung}
\seealso{See also \code{\link{fGeneSigPack}}.}
\examples{
library(MMGeneSigIndex)
data(hovontest)

## .. case of using intensity data
\donttest{gsig <- fHZDCD(hovontest)}

## .. case of using logratio data
\donttest{med <- apply(hovontest, 1, median)}
\donttest{logr <- log2(apply(hovontest, 2, function(x) x / med))}
\donttest{gsig2 <- fHZDCD(logr, val.type="logratio")}

## .. case of using fSingleHZDCD
\donttest{gsig3 <- apply(hovontest, 2, fSingleHZDCD, med)}

## .. sanity check
\donttest{plot(gsig, gsig2)}
\donttest{plot(gsig, gsig3)}
}
\keyword{math}
