\name{Centrosome}
\alias{fCentroIndex}
\alias{fCI}
\alias{fSingleCentroIndex}
\alias{fSingleCI}
\title{Centrosome Index}
\description{
Functions to estimate centrosome index based on MAS5-processed Affymetrix GeneChip data.
}
\usage{
  fCentroIndex(x, val.type="in")
  fCI(x, val.type="in")
  fSingleCentroIndex(x, med, val.type="in")
  fSingleCI(x, med, val.type="in")
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{x}{a numeric matrix (\code{fCentroIndex}, \code{fCI}: gene expression matrix) or a numeric vector (\code{fSingleCentroIndex}, \code{fSingleCI}: gene expression vector).}
  \item{med}{median values for probesets.}
  \item{val.type}{either "intensity" or "logintensity" or "logratio" (value type of \code{x}).}
}
\details{
\code{fCentroIndex} and \code{fCI} estimate centrosome indices of samples in an Affymetrix GeneChip gene expression matrix \code{x}. Preferably, the matrix is supposed to be MAS5-processed but this is not absolutely necessary as far as the row names bear original probesets while columns correspond to samples as usual. \code{fSingleCentroIndex} and \code{fSingleCI} estimate centrosome indices for a named vector \code{x} which corresponds to an individual sample (a column) of a gene expression matrix.

Internally, estimation of centrosome index uses log of median-normalized gene expression matrix. So, when gene expression matrix is provided in intensity type (\code{val.type="intensity"}), we first estimate probeset-wise median values across the whole samples/columns, divide expression intensity of each sample by the estimated median, and take the base-2 logarithm. The procedure goes exactly the same for logarithm type (\code{val.type="logintensity"}) except that division by median is substituted with subtraction by median. For this reason, users should provide probeset-wise median across dataset when using \code{fSingleCentroIndex} or \code{fSingleCI}.
}
\value{
A numeric vector (per each sample/column) for \code{fCentroIndex} and \code{fCI}. 

A number for \code{fSingleCentroIndex} and \code{fSingleCI}.
}
\references{
Chng W-J, Ahmann GJ, Henderson K, \emph{et al.} (2006) Clinical implication of centrosome amplification in plasma cell neoplasm. \emph{Blood} \strong{107:}3669–3675.

Chng W-J, Braggio E, Mulligan G, \emph{et al.} (2008) The centrosome index is a powerful prognostic marker in myeloma and identifies a cohort of patients that might benefit from aurora kinase inhibition. \emph{Blood} \strong{111:}1603–1609.
}
\author{Tae-Hoon Chung}
\seealso{See also \code{\link{fGeneSigPack}}.}
\examples{
library(MMGeneSigIndex)
data(hovontest)

## .. case of using intensity data
\donttest{gsig <- fCI(hovontest)}

## .. case of using logratio data
\donttest{med <- apply(hovontest, 1, median)}
\donttest{logr <- log2(apply(hovontest, 2, function(x) x / med))}
\donttest{gsig2 <- fCI(logr, val.type="logratio")}

## .. case of using fSingleCI
\donttest{gsig3 <- apply(hovontest, 2, fSingleCI, med)}

## .. sanity check
\donttest{plot(gsig, gsig2)}
\donttest{plot(gsig, gsig3)}
}
\keyword{math}
