\name{EMC92}
\alias{fEMC92}
\alias{fSingleEMC92}
\title{EMC92 Signature Index}
\description{
Functions to estimate EMC92 signature indices based on MAS5-processed Affymetrix GeneChip data.
}
\usage{
  fEMC92(x, val.type="in")
  fSingleEMC92(x, med, val.type="in")
}
\arguments{
  \item{x}{a numeric matrix (\code{fEMC92}: gene expression matrix) or a numeric vector (\code{fSingleEMC92}: gene expression vector).}
  \item{med}{median values for probesets.}
  \item{val.type}{either "intensity" or "logintensity" or "logratio" (value type of \code{x}).}
}
\details{
\code{fEMC92} estimates a prognostic signature index of samples in an Affymetrix GeneChip gene expression matrix \code{x}. Preferably, the matrix is supposed to be MAS5-processed but this is not absolutely necessary as far as the row names bear original probesets while columns correspond to samples as usual. 

\code{fSingleEMC92} estimates a prognostic signature index for a named vector \code{x} which corresponds to an individual sample (column vector) of a gene expression matrix.

For implementation details, please refer to \code{\link{fCentroIndex}}.
}
\value{
A numeric vector (per each sample/column) for \code{fEMC92}. 

A number for \code{fSingleEMC92}.
}
\references{
Kuiper R, Broyl A, de Knegt Y, \emph{et al.} (2012) A
gene expression signature for high-risk multiple myeloma. \emph{Leukemia} \strong{26:}2406–2413.
}
\author{Tae-Hoon Chung}
\seealso{See also \code{\link{fGeneSigPack}}.}
\examples{
library(MMGeneSigIndex)
data(hovontest)

## .. case of using intensity data
\donttest{gsig <- fEMC92(hovontest)}

## .. case of using logratio data
\donttest{med <- apply(hovontest, 1, median)}
\donttest{logr <- log2(apply(hovontest, 2, function(x) x / med))}
\donttest{gsig2 <- fEMC92(logr, val.type="logratio")}

## .. case of using fSingleEMC92
\donttest{gsig3 <- apply(hovontest, 2, fSingleEMC92, med)}

## .. sanity check
\donttest{plot(gsig, gsig2)}
\donttest{plot(gsig, gsig3)}
}
\keyword{math}
