\name{GeneSigPack}
\alias{fGeneSigPack}
\alias{fGeneSigPack2}
\title{Multiple Myeloma Prognostic Signature Indices by Batch}
\description{
Functions to estimate a group of multiple myeloma prognostic signature indices en masse based on MAS5-processed Affymetrix GeneChip data.
}
\usage{
  fGeneSigPack(x, val.type="in")
  fGeneSigPack2(x, pack, val.type="in")
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{x}{a numeric matrix (gene expression matrix)}
  \item{pack}{named list of gene signatures (either 2-column data frame or a simple string vector)}
  \item{val.type}{either "intensity" or "logintensity" or "logratio" (value type of \code{x}).}
}
\details{
\code{fGeneSigPack} can be used for 9 fixed prognostic signatures "CINGEC", "CNTI", "EMC92", "HMCL7", "HZDCD", "IFM15", "PI", "UAMS70", "UAMS80" while \code{fGeneSigPack2} can be used for arbitrary number of custom-made signature indices. The signatures for \code{fGeneSigPack2} are provided through \code{pack} which expects a named list where names would be used as the signature identity and values as probe(set)s (and possibly weights) for signature estimation. If a signature is composed of probe(set)s with positive and negative weights that correspond to over- or under-expressed genes, then the signature list item would be a two-column dataframe with probe(set)s in the first column while weights in the second column. If a signature is composed of probe(set)s with all positive weights, then the signature list item would be simple vector of probe(set)s. For a concrete example, please look at the \code{PROBE} object.
}
\value{
A matrix with rows corresponing to signature indices while columns corresponding to samples.
}
\references{
Chung TH, Mulligan G, Fonseca R, Chng WJ (2013) A novel measure of chromosome
instability can account for prognostic difference in multiple myeloma. \emph{PLoS ONE} \strong{8:}e66361.
}
\author{Tae-Hoon Chung}
%\seealso{See also \code{\link{PROBE}} object.}
\examples{
library(MMGeneSigIndex)

\donttest{data(hovontest)}

## .. case of using intensity data
\donttest{gsig <- fGeneSigPack(hovontest)}

## .. case of using logratio data
\donttest{med <- apply(hovontest, 1, median)}
\donttest{logr <- log2(apply(hovontest, 2, function(x) x / med))}
\donttest{gsig2 <- fGeneSigPack(logr, val.type="logratio")}

## .. case of using fGeneSigPack2
\donttest{mysig <- data.frame('PROBE'=rownames(hovontest)[1:10], 'WEIGHT'=sample(c(-1,1), 10, replace=TRUE))}
\donttest{gsig3 <- fGeneSigPack2(hovontest, list("mysig"=mysig))}

## .. sanity check
\donttest{plot(gsig[,1], gsig2[,1])}
\donttest{plot(gsig[1,], gsig3[1,])}
}
\keyword{math}
