\name{HMCL}
\alias{fHMCL7}
\alias{fHMCL248}
\alias{fSingleHMCL7}
\alias{fSingleHMCL248}
\title{Signature Index from IL6 Dependent MM Cell Line}
\description{
Functions to estimate HMCL7 signature index based on MAS5-processed Affymetrix GeneChip data.
}
\usage{
  fHMCL7(x, val.type="in")
  fHMCL248(x, val.type="in")
  fSingleHMCL7(x, med, val.type="in")
  fSingleHMCL248(x, med, val.type="in")
}
\arguments{
  \item{x}{a numeric matrix (\code{fHMCL7}, \code{fHMCL248}: gene expression matrix) or a numeric vector (\code{fSingleIFM15}, \code{fSingleHCML248}: gene expression vector).}
  \item{med}{a numeric vector (median values for probe(set)s).}
  \item{val.type}{either "intensity" or "logintensity" or "logratio" (value type of \code{x}).}
}
\details{
\code{fHMCL7} and \code{fHMCL248} estimate prognostic signature indices of samples in an Affymetrix GeneChip gene expression matrix \code{x}. Preferably, the matrix is supposed to be MAS5-processed but this is not absolutely necessary as far as the row names bear original probesets while columns correspond to samples as usual.

\code{fSingleHMCL7} and \code{fHMCL248} estimate prognostic signature indices for a named vector \code{x} which corresponds to an individual sample (column vector) of a gene expression matrix.

For implementation details, please refer to \code{\link{fCentroIndex}}.
}
\value{
A numeric vector (per each sample/column) for \code{fHMCL7} and \code{fHMCL248}. 

A number for \code{fSingleHMCL7} and \code{fSingleHCML248}.
}
\references{
Moreaux J, Klein B, Bataille R, \emph{et al.} (2011) A high-risk signature for patients with multiple myeloma established from the molecular classification of human myeloma cell lines. \emph{Haematologica} \strong{96:}574–582.
}
\author{Tae-Hoon Chung}
\seealso{See also \code{\link{fGeneSigPack}}.}
\examples{
library(MMGeneSigIndex)
data(hovontest)

## .. case of using intensity data
\donttest{gsig <- fHMCL7(hovontest)}

## .. case of using logratio data
\donttest{med <- apply(hovontest, 1, median)}
\donttest{logr <- log2(apply(hovontest, 2, function(x) x / med))}
\donttest{gsig2 <- fHMCL7(logr, val.type="logratio")}

## .. case of using fSingleHMCL7
\donttest{gsig3 <- apply(hovontest, 2, fSingleHMCL7, med)}

## .. sanity check
\donttest{plot(gsig, gsig2)}
\donttest{plot(gsig, gsig3)}
}
\keyword{math}
