\name{IFM15}
\alias{fIFM15}
\alias{fSingleIFM15}
\title{Signature Index from Intergroupe Francophone du Myelome study}
\description{
Functions to estimate IFM15 signature index based on MAS5-processed Affymetrix GeneChip data.
}
\usage{
fIFM15(x, val.type="in")
fSingleIFM15(x, med, val.type="in")
}
\arguments{
  \item{x}{a numeric matrix (\code{fIFM15}: gene expression matrix) or a numeric vector (\code{fSingleIFM15}: gene expression vector).}
  \item{med}{a numeric vector (median values for probe(set)s).}
  \item{val.type}{either "intensity" or "logintensity" or "logratio" (value type of \code{x}).}
}
\details{
\code{fIFM15} estimates a prognostic signature index of samples in an Affymetrix GeneChip gene expression matrix \code{x}. Preferably, the matrix is supposed to be MAS5-processed but this is not absolutely necessary as far as the row names bear original probesets while columns correspond to samples as usual.

\code{fSingleIFM15} estimates a prognostic signature index for a named vector \code{x} which corresponds to an individual sample (column vector) of a gene expression matrix.

For implementation details, please refer to \code{\link{fCentroIndex}}.
}
\value{
A numeric vector (per each sample/column) for \code{fIFM15}. 

A number for \code{fSingleIFM15}.
}
\references{
Decaux O, Lode L, Magrangeas F, \emph{et al.} (2008) Prediction of survival in multiple myeloma based on gene expression profiles reveals cell cycle and chromosomal instability signatures in high-risk patients and hyperdiploid signatures in low-risk patients: a study of the Intergroupe Francophone du Myelome. \emph{J Clin Oncol} \strong{26:}4798–4805.
}
\author{Tae-Hoon Chung}
\seealso{See also \code{\link{fGeneSigPack}}.}
\examples{
library(MMGeneSigIndex)
data(hovontest)

## .. case of using intensity data
\donttest{gsig <- fIFM15(hovontest)}

## .. case of using logratio data
\donttest{med <- apply(hovontest, 1, median)}
\donttest{logr <- log2(apply(hovontest, 2, function(x) x / med))}
\donttest{gsig2 <- fIFM15(logr, val.type="logratio")}

## .. case of using fSingleIFM15
\donttest{gsig3 <- apply(hovontest, 2, fSingleIFM15, med)}

## .. sanity check
\donttest{plot(gsig, gsig2)}
\donttest{plot(gsig, gsig3)}
}
\keyword{math}
