\name{Proliferation}
\alias{fProlifIndex}
\alias{fPI}
\alias{fSingleProlifIndex}
\alias{fSinglePI}
\title{Proliferation Index}
\description{
Functions to estimate proliferation index based on MAS5-processed Affymetrix GeneChip data.
}
\usage{
  fProlifIndex(x, val.type="in")
  fPI(x, val.type="in")
  fSingleProlifIndex(x, med, val.type="in")
  fSinglePI(x, med, val.type="in")
}
\arguments{
  \item{x}{a numeric matrix (\code{fProlifIndex}, \code{fPI}: gene expression matrix) or a numeric vector (\code{fSingleProlifIndex}, \code{fSinglePI}: gene expression vector).}
  \item{med}{a numeric vector (median values for probe(set)s).}
  \item{val.type}{either "intensity" or "logintensity" or "logratio" (value type of \code{x}).}
}
\details{
\code{fProlifIndex} and \code{fPI} estimate proliferation indices of samples in an Affymetrix GeneChip gene expression matrix \code{x}. Preferably, the matrix is supposed to be MAS5-processed but this is not absolutely necessary as far as the row names bear original probesets while columns correspond to samples as usual. 

\code{fSingleProlifIndex} and \code{fSinglePI} estimate proliferation indices for a named vector \code{x} which corresponds to an individual sample (a column) of a gene expression matrix.

For implementation details, please refer to \code{\link{fCentroIndex}}.
}
\value{
A numeric vector (per each sample/column) for \code{fProlifIndex} and \code{fPI}. 

A number for \code{fSingleProlifIndex} and \code{fSinglePI}.
}
\references{
Hose D, R\`{e}me T, Hielscher T, \emph{et al.} (2011) Proliferation is a central independent prognostic factor and target for personalized and risk-adapted treatment in multiple myeloma. \emph{Haematologica} \strong{96:}87-95.
}
\author{Tae-Hoon Chung}
\seealso{See also \code{\link{fGeneSigPack}}.}
\examples{
library(MMGeneSigIndex)

\donttest{data(hovontest)}

## .. case of using intensity data
\donttest{gsig <- fPI(hovontest)}

## .. case of using logratio data
\donttest{med <- apply(hovontest, 1, median)}
\donttest{logr <- log2(apply(hovontest, 2, function(x) x / med))}
\donttest{gsig2 <- fPI(logr, val.type="logratio")}

## .. case of using fSinglePI
\donttest{gsig3 <- apply(hovontest, 2, fSinglePI, med)}

## .. sanity check
\donttest{plot(gsig, gsig2)}
\donttest{plot(gsig, gsig3)}
}
\keyword{math}
