\name{UAMS}
\alias{fUAMS70}
\alias{fUAMS80}
\alias{fSingleUAMS70}
\alias{fSingleUAMS80}
\title{University of Arkansas Medical School (UAMS) Signature Indices}
\description{
Functions to estimate UAMS-devised indices based on MAS5-processed Affymetrix GeneChip data.
}
\usage{
  fUAMS70(x, val.type="in")
  fUAMS80(x, val.type="in")
  fSingleUAMS70(x, med, val.type="in")
  fSingleUAMS80(x, med, val.type="in")
}
\arguments{
  \item{x}{a numeric matrix (\code{fUAMS70}, \code{fUAMS80}: gene expression matrix) or a numeric vector (\code{fSingleUAMS70}, \code{fSingleUAMS80}: gene expression vector).}
  \item{med}{a numeric vector (median values for probe(set)s).}
  \item{val.type}{either "intensity" or "logintensity" or "logratio" (value type of \code{x}).}
}
\details{
\code{fUAMS70} and \code{fUAMS80} estimate prognostic signature indices of samples in an Affymetrix GeneChip gene expression matrix \code{x} designed by researchers in University of Arkansas Medical School (UAMS). Preferably, the matrix is supposed to be MAS5-processed but this is not absolutely necessary as far as the row names bear original probesets while columns correspond to samples as usual.

\code{fSingleUAMS70} and \code{fSingleUAMS80} estimate UAMS prognostic signature indices for a named vector \code{x} which corresponds to an individual sample (a column) of a gene expression matrix.

For implementation details, please refer to \code{\link{fCentroIndex}}.
}
\value{
A numeric vector (per each sample/column) for \code{fUAMS70} and \code{fUAMS80}. 

A number for \code{fSingleUAMS70} and \code{fSingleUAMS80}.
}
\references{
Shaughnessy JD, Zhan F, Burington BE, \emph{et al.} (2006) A validated gene expression model of high-risk multiple myeloma is defined by deregulated expression of genes mapping to chromosome 1. \emph{Blood} \strong{109:}2276–2284.

Shaughnessy JD, Qu P, Usmani S, \emph{et al.} (2011) Pharmacogenomics of bortezomib test-dosing identifies hyperexpression of proteasome genes, especially PSMD4, as novel high-risk feature in myeloma treated with Total Therapy 3. \emph{Blood} \strong{118:}3512-3524.
}
\author{Tae-Hoon Chung}
\seealso{See also \code{\link{fGeneSigPack}}.}
\examples{
library(MMGeneSigIndex)
data(hovontest)

## .. case of using intensity data
\donttest{gsig <- fUAMS70(hovontest)}

## .. case of using logratio data
\donttest{med <- apply(hovontest, 1, median)}
\donttest{logr <- log2(apply(hovontest, 2, function(x) x / med))}
\donttest{gsig2 <- fUAMS70(logr, val.type="logratio")}

## .. case of using fSingleEMC92
\donttest{gsig3 <- apply(hovontest, 2, fSingleUAMS70, med)}

## .. sanity check
\donttest{plot(gsig, gsig2)}
\donttest{plot(gsig, gsig3)}
}
\keyword{math}
