\name{Utilities}
\alias{findex.mat}
\alias{findex.mat.bare.bare}
\alias{findex.mat.bare.weight}
\alias{findex.mat.norm.bare}
\alias{findex.mat.norm.weight}
\title{Utility Functions for Signature Index Estimation}
\description{
Basic functions for estimating gene expression signature indices with a gene expression matrix.
}
\usage{
  findex.mat(x, prb, val.type="in", alg="med", normalize=T, weight=T)
  findex.mat.bare.bare(x, prb, val.type="in", alg="med")
  findex.mat.bare.weight(x, prb, val.type="in", alg="med")
  findex.mat.norm.bare(x, prb, val.type="in", alg="med")
  findex.mat.norm.weight(x, prb, val.type="in", alg="med")
}
\arguments{
  \item{x}{a numeric matrix (gene expression matrix)}
  \item{prb}{a two-column data frame (column 1: probe(set) ids, column 2: weights) for \code{findex.mat} and \code{findex.*.weight}; a string vector (of probe(set) ids) for \code{findex.mat} with \code{weight=F} and \code{findex.*.bare}}
  \item{val.type}{either "intensity" (default) or "logintensity" or "logratio"; value type of \code{x}}
  \item{alg}{either "median" (default) or "mean"; signature index estimation, median or mean?}
  \item{normalize}{a logical (perform median-normalization of \code{x}? default: \code{TRUE})}
  \item{weight}{a logical (signature contains positive- and negative-weights (\code{TRUE}) or just positive-weight ones (\code{FALSE})? default: \code{TRUE})}
}
\details{
When a gene expression matrix and a gene signature are prepared, \code{findex.mat} is the basic function for estimating the signature index. The default option setting is recommended for a MAS5 processed Affymetrix GeneChip expression matrix with a signature of over- as well as under-expressed probeset members. If the signature contains only over-expressed probesets instead, then the option would be changed as \code{weight=F} or, if the gene expression matrix is prepared with RMA algorithm instead, then the option would be changed as \code{val.type="logintensity"} with all other options untouched.
}
\value{a numeric vector}
\references{
Chung TH, Mulligan G, Fonseca R, Chng WJ (2013) A novel measure of chromosome instability can account for prognostic difference in multiple myeloma. \emph{PLoS ONE} \strong{8:}e66361.
}
\author{Tae-Hoon Chung}
\examples{
##---- Should be DIRECTLY executable !! ----
##-- ==>  Define data, use random,
##--	or do  help(data=index)  for the standard data sets.

## The function is currently defined as
}
\keyword{math}
\keyword{utility}
