\name{fcategorize}
\alias{fcategorize}
\alias{fcategorize2}
\alias{fcategorize.rev}
\title{Function to categorize input vector into discrete levels}
\description{These functions categorize input vector into discrete levels.}
\usage{
fcategorize(x, nlev, by=c("equal.lev", "equal.quantile", "fixed.lev", "fixed.quantile", "fixed.range"))
fcategorize2(x, nlev, by=c("equal.lev", "equal.quantile", "fixed.lev", "fixed.quantile", "fixed.range"))
fcategorize.rev(x)
}
\arguments{
  \item{x}{a numeric vector}
  \item{nlev}{a numeric vector}
  \item{by}{one of "equal.lev", "equal.quantile", "fixed.lev", "fixed.quantile", "fixed.range"}
}
\value{\code{fcategorize} produces a numeric vector in \eqn{1, \ldots, nlev} range where 1 represents the lowest value level and \code{nlev} represents the highest value level. \code{fcategorize2} produces a list with 2 elements, a numeric vector of level cutoff values and another numeric vector of discrete levels. \code{fcategorize.rev} reverses the discrete level indicators so that 1 represents the highest value level and \code{nlev} represents the lowest one.}
\details{If \code{by} is "equal.lev", input data is divided into \code{nlev} number of euqal intervals. If \code{by} is "equal.quantile", input data is divided into \code{nlev} number of equal quatiles. If \code{by} is "fixed.lev", input data is divided into discrete levels using the values in \code{nlev} as cutoff values. If \code{by} is "fixed.quantile", input data is divided into discrete levels using the values in \code{nlev} as cutoff quantile values. If \code{by} is "fixed.range", input data is divided into discrete levels at fixed ranges in \code{nlev}.}
\note{For cases where \code{by} is "equal.lev" or "equal.quantile", \code{nlev} should be integers > 1. For the case where \code{by} is "fixed.lev", \code{nlev} should be within the input data range. For other cases, \code{nlev} should be between 0 and 1.}
\author{Tae-Hoon Chung}
\examples{
##---- Should be DIRECTLY executable !! ----
##-- ==>  Define data, use random,
##--	or do  help(data=index)  for the standard data sets.

## The function is currently defined as
x <- rnorm(100)
y <- fcategorize(x, 3, by="equal.lev")
table(y)

y <- fcategorize(x, 3, by="equal.quantile")
table(y)

y <- fcategorize(x, 0.5, by="fixed.lev")
table(y)

y <- fcategorize(x, 0.5, by="fixed.quantile")
table(y)

y <- fcategorize(x, 0.5, by="fixed.range")
table(y)

z <- fcategorize.rev(y)
cbind(y, z)[1:25]
}
\keyword{utility}% __ONLY ONE__ keyword per line
